==> nextcloud-18.0.4.tgz: nextcloud/apps/survey_client/l10n/fi.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Viimeisin raportti lähetetty: {on}",
    "An error occurred while sending your report." : "Tapahtui virhe lähetettäessä raporttia.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Sovelluslista <em>(jokaisen sovelluksen osalta: nimi, versio, onko käytössä)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Tietokantaympäristö <em>(tyyppi, versio, tietokannan koko)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Salaustietoa <em>(onko salaus käytössä, mikä on oletusmoduuli)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Jakojen määrä <em>(tyyppi ja käyttöoikeusasetukset)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-ympäristö <em>(versio, muistin raja, maks. suoritusaika, maks. tiedostokoko)</em>",
    "Usage survey" : "Käyttötutkimus",
    "Help improve Nextcloud" : "Auta parantamaan Nextcloudia",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Haluatko auttaa meitä Nextcloudin kehittämisessä lähettämällä anonyymiä tietoa asetuksistasi ja käytöstäsi? Voit estää tietojen lähettämisen koska tahansa ylläpitoasetuksissa.",
    "Not now" : "Ei nyt",
    "Send usage" : "Lähetä käyttötiedot",
    "Never" : "Ei koskaan",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Voit auttaa Nextcloudin kehittämistä lähettämällä tietoja nykyisestä asennuksesta ja käytöstä.",
    "Send new report now" : "Lähetä uusi raportti nyt",
    "Send usage survey monthly" : "Lähetä käyttötutkimusraportti kuukausittain",
    "Data to send" : "Lähetettävät tiedot",
    "Last report sent on: %s" : "Viimeisin raportti lähetetty: %s",
    "Last report" : "Edellinen raportti"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-19.0.8.tgz: nextcloud/apps/survey_client/l10n/fi.js <==
OC.L10N.register(
    "survey_client",
    {
    "Last report sent on: {on}" : "Viimeisin raportti lähetetty: {on}",
    "An error occurred while sending your report." : "Tapahtui virhe lähetettäessä raporttia.",
    "App list <em>(for each app: name, version, enabled status)</em>" : "Sovelluslista <em>(jokaisen sovelluksen osalta: nimi, versio, onko käytössä)</em>",
    "Database environment <em>(type, version, database size)</em>" : "Tietokantaympäristö <em>(tyyppi, versio, tietokannan koko)</em>",
    "Encryption information <em>(is it enabled?, what is the default module)</em>" : "Salaustietoa <em>(onko salaus käytössä, mikä on oletusmoduuli)</em>",
    "Number of shares <em>(per type and permission setting)</em>" : "Jakojen määrä <em>(tyyppi ja käyttöoikeusasetukset)</em>",
    "PHP environment <em>(version, memory limit, max. execution time, max. file size)</em>" : "PHP-ympäristö <em>(versio, muistin raja, maks. suoritusaika, maks. tiedostokoko)</em>",
    "Usage survey" : "Käyttötutkimus",
    "Help improve Nextcloud" : "Auta parantamaan Nextcloudia",
    "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "Haluatko auttaa meitä Nextcloudin kehittämisessä lähettämällä anonyymiä tietoa asetuksistasi ja käytöstäsi? Voit estää tietojen lähettämisen koska tahansa ylläpitoasetuksissa.",
    "Not now" : "Ei nyt",
    "Send usage" : "Lähetä käyttötiedot",
    "Never" : "Ei koskaan",
    "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "Lähetä anonymisoitua tietoa Nextcloudille, jotta voimme parantaa Nextcloudia.",
    "You can help improve Nextcloud by sending us some data about your current setup and usage." : "Voit auttaa Nextcloudin kehittämistä lähettämällä tietoja nykyisestä asennuksesta ja käytöstä.",
    "Send new report now" : "Lähetä uusi raportti nyt",
    "Send usage survey monthly" : "Lähetä käyttötutkimusraportti kuukausittain",
    "Data to send" : "Lähetettävät tiedot",
    "Last report sent on: %s" : "Viimeisin raportti lähetetty: %s",
    "Last report" : "Edellinen raportti"
},
"nplurals=2; plural=(n != 1);");
